import pywintypes
import win32file
import win32con
import os
import time
import re
import sys

def main():
	fileDir = raw_input('Enter the directory where your images are: ')
	# Exit if no input
	if fileDir == '':
		sys.exit(0)
	# Add a trailing slash if one doesn't exist
	if fileDir[-1:] != '\\':
		fileDir = fileDir + '\\'
	for fileName in os.listdir(fileDir):
		# Only continue if file type is supported
		if (('.jpg' in fileName) or ('.3g2' in fileName) or ('.3gp' in fileName)):
			# Only continue if the filename starts with 10 digits
			if (re.match('^\d{10}', fileName)):
				print('Applying changes to "' + fileName + '"...')
				# Get data from filename
				month = fileName[0:2]
				day = fileName[2:4]
				year = fileName[4:6]
				# Corrects for bug in VX8300 software that 
				# causes the year "2000" to be printed as "00"
				# in the filename
				if year == '00':
					year = '10'
				hour = fileName[6:8]
				minute = fileName[8:10]
				# Create time string from filename data
				timeString = (year + " " + month + " " + day +
					" " + hour + " " + minute)
				# Print out the time info to be applied to the file
				print("20" + year + "-" + month + "-" + day +
					" " + hour + ":" + minute + ":00")
				# Create the Time structure used to change
				# the file created time later
				timeStruct = time.strptime(timeString, "%y %m %d %H %M")
				fileTime = pywintypes.Time(timeStruct)
				# Set the epoch time based upon the timeStruct
				timeEpoch = time.mktime(timeStruct)
				# Change the file creation, modified, and accessed times
				changeFileCreationTime(fileDir + fileName, fileTime)
				os.utime(fileDir + fileName, (timeEpoch, timeEpoch))
		else:
			print('Skipping "' + fileName + '"...')
	print("Done!")

def changeFileCreationTime(fname, newtime):
	# Create the Time object
    wintime = pywintypes.Time(newtime)
	# Create the file object
    winfile = win32file.CreateFile(
        fname, win32con.GENERIC_WRITE,
        win32con.FILE_SHARE_READ | win32con.FILE_SHARE_WRITE | win32con.FILE_SHARE_DELETE,
        None, win32con.OPEN_EXISTING,
        win32con.FILE_ATTRIBUTE_NORMAL, None)
	# Set the file created time
    win32file.SetFileTime(winfile, wintime, None, None)
	# Close the file object
    winfile.close()

if __name__ == "__main__":
    main()